@@ -13,6 +13,10 @@ def list_():
     return [" TEXT", 'list']
 
 
+def dict_():
+    return [" TEXT", 'dict']
+
+
 def add_quotes(value):
     if isinstance(value, str) or isinstance(value, list):
         value = '"{}"'.format(str(value).replace('"', "'"))
@@ -36,7 +40,7 @@ def get_visual(obj):
     return [i for i in vars(obj).values()]
 
 
-def convert_to_list(obj):
+def convert(obj):
     return literal_eval(obj)
 
 
